/*++

Copyright (c) Pico Systems Co., Ltd.

Module Name:

    gpio.h

Abstract:

    General Purpose I/O Interface device driver
    GPIO Dynamic Link library definitions

Revision History:

    31/Mar/2014   Created by Makoto Ito
	
--*/

#include "windows.h"

#ifndef GPIO_H
#define GPIO_H


// The following ifdef block is the standard way of creating macros
// which make exporting from a DLL simpler.

#ifdef GPIO_EXPORTS
#define GPIO_API __declspec(dllexport)
#else
#define GPIO_API __declspec(dllimport)
#endif


// Type Definition

typedef PVOID	GPIO_HANDLE;
typedef ULONG	GPIO_STATUS;


// Device status

enum
{
	GPIO_OK,
	GPIO_INVALID_HANDLE,
	GPIO_IO_ERROR,
	GPIO_INVALID_PARAMETER,
	GPIO_NO_RESPONSE,
	GPIO_OTHER_ERROR,
	GPIO_ACK1,
	GPIO_ACK2,
	GPIO_ACK3,
	GPIO_ACK4,
	GPIO_NAK,
	GPIO_BUSY,
	GPIO_L_LEVEL,
	GPIO_H_LEVEL
};


// Device Type

#define	GPIO_BILL 0x58
#define	GPIO_COIN 0x60
#define	GPIO_CARD 0xE0


// Function for Export

GPIO_API
GPIO_STATUS WINAPI GPIO_ScanInterface
(
	unsigned int* puiNumber
);

GPIO_API
GPIO_STATUS WINAPI GPIO_OpenInterface
(
	unsigned int uiInterface,
	GPIO_HANDLE *gpioHandle
);

GPIO_API
GPIO_STATUS WINAPI GPIO_CloseInterface
(
	GPIO_HANDLE gpioHandle
);

GPIO_API
GPIO_STATUS WINAPI GPIO_Input
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char* pucData
);

GPIO_API
GPIO_STATUS WINAPI GPIO_Output
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucData
);

GPIO_API
GPIO_STATUS WINAPI GPIO_BitTest
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucBit
);

GPIO_API
GPIO_STATUS WINAPI GPIO_BitSet
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucBit
);

GPIO_API
GPIO_STATUS WINAPI GPIO_BitReset
(
	GPIO_HANDLE gpioHandle,
	char cPort,
	unsigned char ucBit
);

#endif
